"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShikiProvider = ShikiProvider;
exports.useShiki = useShiki;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = require("react");
var _jsxRuntime = require("react/jsx-runtime");
/* eslint-disable no-console */

const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/(0, _react.createContext)(null);
function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = (0, _react.useState)(null);
  const [isReady, setIsReady] = (0, _react.useState)(false);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    const initHighlighter = async () => {
      try {
        _log('Initializing with languages:', initialLanguages.map(l => l.name));
        _log('Initializing with themes:', initialThemes.map(t => t.name));
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        const defaultTheme = initialThemes[0];
        if (!defaultTheme || !defaultTheme.name) {
          throw new Error('Invalid theme format');
        }
        _log('Theme details:', {
          name: defaultTheme.name,
          type: defaultTheme.type,
          tokenColors: defaultTheme.tokenColors?.length,
          settings: defaultTheme.settings?.length,
          colors: Object.keys(defaultTheme.colors || {}).length
        });
        const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
          forgiving: true,
          cache: new Map()
        });
        _log('Created regex engine');

        // Process the theme's token rules
        const processedTheme = {
          name: defaultTheme.name,
          type: defaultTheme.type,
          colors: defaultTheme.colors || {},
          // Convert tokenColors to the exact format expected by Shiki
          settings: [
          // Default colors first
          {
            name: 'Default',
            settings: {
              foreground: defaultTheme.colors?.['editor.foreground'],
              background: defaultTheme.colors?.['editor.background']
            }
          },
          // Then convert each token color rule, filtering out rules without scopes
          ...(defaultTheme.tokenColors || []).filter(rule => rule.scope) // Only include rules with scopes
          .map(rule => ({
            name: rule.name || '',
            scope: Array.isArray(rule.scope) ? rule.scope : typeof rule.scope === 'string' ? rule.scope.split(',').map(s => s.trim()) : [],
            settings: {
              foreground: rule.settings.foreground,
              fontStyle: rule.settings.fontStyle,
              background: rule.settings.background
            }
          }))]
        };
        _log('Theme token rules:', {
          defaultColors: processedTheme.settings[0],
          firstRule: processedTheme.settings[1],
          totalRules: processedTheme.settings.length,
          sampleScopes: processedTheme.settings.slice(1, 4).filter(rule => 'scope' in rule).map(rule => ({
            scope: rule.scope,
            color: rule.settings.foreground
          }))
        });
        const highlighterInstance = await (0, _core.createHighlighterCore)({
          themes: [processedTheme],
          langs: initialLanguages,
          engine
        });

        // Test with a specific token we know should be colored
        const testCode = `
      // This is a comment
      function test() {
        const str = "hello";
        return str;
      }
    `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: 'typescript',
          theme: processedTheme.name,
          includeExplanation: true
        });
        _log('Test token scopes:', testTokens.tokens[0]?.map(token => ({
          content: token.content,
          color: token.color,
          scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
          matches: token.explanation?.[0]?.scopes.flatMap(s => s.themeMatches || []).map(m => ({
            scope: m.scope,
            color: m.settings.foreground
          }))
        })));
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = (0, _react.useMemo)(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
function useShiki() {
  const context = (0, _react.useContext)(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map