"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        _log('Initializing with languages:', initialLanguages.map(l => l.name));
        _log('Initializing with themes:', initialThemes.map(t => t.name));
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        const defaultTheme = initialThemes[0];
        if (!defaultTheme || !defaultTheme.name) {
          throw new Error('Invalid theme format');
        }
        _log('Theme details:', {
          name: defaultTheme.name,
          type: defaultTheme.type,
          tokenColors: defaultTheme.tokenColors?.length,
          settings: defaultTheme.settings?.length,
          colors: Object.keys(defaultTheme.colors || {}).length
        });
        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map()
        });
        _log('Created regex engine');

        // Process the theme's token rules
        const processedTheme = {
          name: defaultTheme.name,
          type: defaultTheme.type,
          colors: defaultTheme.colors || {},
          // Convert tokenColors to the exact format expected by Shiki
          settings: [
          // Default colors first
          {
            name: 'Default',
            settings: {
              foreground: defaultTheme.colors?.['editor.foreground'],
              background: defaultTheme.colors?.['editor.background']
            }
          },
          // Then convert each token color rule, filtering out rules without scopes
          ...(defaultTheme.tokenColors || []).filter(rule => rule.scope) // Only include rules with scopes
          .map(rule => ({
            name: rule.name || '',
            scope: Array.isArray(rule.scope) ? rule.scope : typeof rule.scope === 'string' ? rule.scope.split(',').map(s => s.trim()) : [],
            settings: {
              foreground: rule.settings.foreground,
              fontStyle: rule.settings.fontStyle,
              background: rule.settings.background
            }
          }))]
        };
        _log('Theme token rules:', {
          defaultColors: processedTheme.settings[0],
          firstRule: processedTheme.settings[1],
          totalRules: processedTheme.settings.length,
          sampleScopes: processedTheme.settings.slice(1, 4).filter(rule => 'scope' in rule).map(rule => ({
            scope: rule.scope,
            color: rule.settings.foreground
          }))
        });
        const highlighterInstance = await createHighlighterCore({
          themes: [processedTheme],
          langs: initialLanguages,
          engine
        });

        // Test with a specific token we know should be colored
        const testCode = `
      // This is a comment
      function test() {
        const str = "hello";
        return str;
      }
    `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: 'typescript',
          theme: processedTheme.name,
          includeExplanation: true
        });
        _log('Test token scopes:', testTokens.tokens[0]?.map(token => ({
          content: token.content,
          color: token.color,
          scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
          matches: token.explanation?.[0]?.scopes.flatMap(s => s.themeMatches || []).map(m => ({
            scope: m.scope,
            color: m.settings.foreground
          }))
        })));
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map